@@ -22,7 +22,7 @@ mewma.arl <- function(l, cE, p, delta=0, hs=0, r=20, ntype=NULL, qm0=20, qm1=qm0
     }
   }
   
-  qtyp <- pmatch(tolower(ntype), c("gl", "co", "ra", "cc", "mc", "sr", "co2", "gl2", "gl3", "gl4", "gl5", "co3", "co4")) - 1
+  qtyp <- pmatch(tolower(ntype), c("gl", "co", "ra", "cc", "mc", "sr", "co2", "gl2", "gl3", "gl4", "gl5", "co3", "co4", "ngl1", "ngl2", "ngl3", "ngl4", "ngl5")) - 1
   if ( is.na(qtyp) )		stop("invalid type of numerical algorithm")
 
   arl <- .C("mewma_arl", as.double(l), as.double(cE),
@@ -33,4 +33,4 @@ mewma.arl <- function(l, cE, p, delta=0, hs=0, r=20, ntype=NULL, qm0=20, qm1=qm0
 
   names(arl) <- NULL
   arl
-}
\ No newline at end of file
+}
