@@ -9,7 +9,7 @@ pois.ewma.arl <- function(lambda, AL, AU, mu0, z0, mu, sided="two", rando=FALSE,
   if ( z0 < hL | z0 > hU )             stop("wrong headstart")
   ctyp <- pmatch(sided, c("upper", "lower", "two")) - 1
   if ( is.na(ctyp) )                    stop("invalid ewma type")
-  mcd <- pmatch(mcdesign, c("classic", "transfer")) - 1
+  mcd <- pmatch(mcdesign, c("classic", "transfer", "cW", "tW")) - 1
   if ( is.na(mcd) )                    stop("invalid mcdesign value")
   if ( rando ) {
     if ( gL < 0 | gL > 1 )              stop("wrong value for gL") 
